@@ -1,5 +1,5 @@
 package Dir::Manifest;
-$Dir::Manifest::VERSION = '0.0.1';
+$Dir::Manifest::VERSION = '0.0.2';
 use strict;
 use warnings;
 
@@ -81,6 +81,15 @@ sub text
     return Dir::Manifest::Slurp::slurp( $self->get_obj($key)->fh, $opts );
 }
 
+sub texts_dictionary
+{
+    my ( $self, $args ) = @_;
+
+    my $opts = $args->{slurp_opts};
+
+    return +{ map { $_ => $self->text( $_, $opts ) } @{ $self->get_keys } };
+}
+
 1;
 
 __END__
@@ -95,7 +104,7 @@ Dir::Manifest
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 DESCRIPTION
 
@@ -113,7 +122,7 @@ Dir::Manifest - treat a directory and a manifest file as a hash/dictionary of ke
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 METHODS
 
@@ -138,6 +147,11 @@ Throws an error if $key was not given in the manifest.
 
 Slurps the key using L<Dir::Manifest::Slurp>
 
+=head2 my $hash_ref = $obj->texts_dictionary( {slurp_opts => {},} );
+
+Returns a hash reference (a dictionary) containing all keys and their slurped contents
+as values. C<'slurp_opts'> is passed to text().
+
 =head1 DEDICATION
 
 This code is dedicated to the memory of L<Jonathan Scott Duff,https://metacpan.org/author/DUFF>
